TurboGears2 Ming
------------------

tgming is used by TurboGears2 to support ming backend. To create
a ming project just use quickstart command with --ming option
it will automatically setup tgming and all the required dependencies

